"""

Timestamp Paginator for Django.

Umut Bozkurt - @umutbozkurt
MIT Licence

"""


from django_timestamp_paginator.paginator import TimestampPaginator, Page

__all__ = [
    'TimestampPaginator',
    'Page'
]
